==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Asiakas"

, "State"
: ""

, "Role"
: ""

, "Source"
: "Lähde"

, "Start"
: "Alku"

, "Scheduled end"
: "Arvioitu päättyminen"

, "End"
: "Loppu"

, "Turnover"
: ""

, "Probability"
: ""

, "Folder"
: "Kansio"

, "Updated by"
: "Päivitetty"

, "Updated Fields:"
: "Päivitetyt kentät:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: ""

, "Lead %s has been changed"
: "Johtaja %s on vaihdettu"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Johtaja %s on luotu"

, "Lead Data"
: ""

, "Leadstate"
: ""

, "Leadtype"
: ""

, "Leadsource"
: ""

, "End Scheduled"
: ""

, "Contacts"
: "Yhteystiedot"

, "Address"
: "Osoite"

, "Telephone"
: "Puhelin"

, "Email"
: "Sähköposti"

, "Tasks"
: ""

, "Due Date"
: ""

, "Priority"
: ""

, "Products"
: "Tuotteet"

, "low"
: "alhainen"

, "normal"
: "normaali"

, "high"
: "korkea"

, "urgent"
: "tärkeä"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications Emails for own actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: "Oletus suosikki"

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: "hallitse jaettujen johtajien kansioita"

, "Create new shared lead folders"
: "Luo uusi jaettu johtajan kansio"

, "manage shared leads favorites"
: "hallitse jaettujen kansioiden suosikeita"

, "Create or update shared leads favorites"
: "Luo tai päivitä jaettujen johtajien suosikkeja"

, "Contact"
: ""

, "CRM Role"
: ""

, "Lead, Leads"
: [
  ""
 ,""

]
, "lead list, lead lists"
: [
  ""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Lead name"
: ""

, "Last Modified Time"
: "Muokattu viimeksi"

, "Last Modified By"
: "Muokkasi viimeksi"

, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luonut"

, "Estimated end"
: ""

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Partneri"

, "Phone"
: "Puhelin"

, "Mobile"
: "Matkapuhelin"

, "Fax"
: "Fax"

, "E-Mail"
: "Sähköposti"

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Tila"

, "Change type to Customer"
: ""

, "Responsible"
: ""

, "Change type to Responsible"
: ""

, "Change type to Partner"
: ""

, "Change contact type"
: ""

, "Search for Contacts to add ..."
: ""

, "Name"
: "Nimi"

, "Data"
: "Tiedot"

, "Cellphone"
: "Matkapuhelin"

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "Muokkaa {0}"

, "Edit selected {0}"
: "Muokkaa valittuja {0}"

, "No Tasks to display"
: ""

, "Summary"
: "Yhteenveto"

, "Add a task..."
: ""

, "Percent"
: "Prosenttia"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: "Kuvaus"

, "Enter description"
: ""

, "New Lead"
: ""

, "Product"
: "Tuote"

, "Price"
: "Hinta"

, "Quantity"
: "Määrä"

, "Search for Products to add ..."
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: ""

, "contacted"
: ""

, "waiting for feedback"
: "Odottaa yhteydenotto"

, "quote sent"
: ""

, "accepted"
: "Hyväksytty"

, "lost"
: "menetetty"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Jälleenmyyjä"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Oletus suosikki"

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Responsible"
: ""

, "Partner"
: "Partneri"

, "Customer"
: "Asiakas"

, "Leadstate"
: ""

, "Leadtype"
: ""

, "Leadsource"
: ""

, "Probability"
: ""

, "Turnover"
: ""

, "Estimated end"
: ""

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Tasks"
: ""

, "No Tasks to display"
: ""

, "Summary"
: "Yhteenveto"

, "Add a task..."
: ""

, "Due Date"
: ""

, "Priority"
: ""

, "Percent"
: "Prosenttia"

, "Status"
: "Tila"

, "Organizer"
: ""

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "Muokkaa {0}"

, "Edit selected {0}"
: "Muokkaa valittuja {0}"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""
 ,""

]
, "Select Lead"
: ""

, "Role"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "Puhelin"

, "Mobile"
: "Matkapuhelin"

, "Fax"
: "Fax"

, "E-Mail"
: "Sähköposti"

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Alku"

, "Change type to Customer"
: ""

, "Change type to Responsible"
: ""

, "Change type to Partner"
: ""

, "Change contact type"
: ""

, "Search for Contacts to add ..."
: ""

, "Name"
: "Nimi"

, "Address"
: "Osoite"

, "Data"
: "Tiedot"

, "Cellphone"
: "Matkapuhelin"

, "End"
: "Loppu"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "Tuotteet"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: "Kuvaus"

, "Enter description"
: ""

, "lead list, lead lists"
: [
  ""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: "Muokattu viimeksi"

, "Last Modified By"
: "Muokkasi viimeksi"

, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luonut"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Tuote"

, "Price"
: "Hinta"

, "Quantity"
: "Määrä"

, "Search for Products to add ..."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: ""

, "contacted"
: ""

, "waiting for feedback"
: "Odottaa yhteydenotto"

, "quote sent"
: ""

, "accepted"
: "Hyväksytty"

, "lost"
: "menetetty"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Jälleenmyyjä"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: ""

, "Source"
: "Lähde"

, "Scheduled end"
: "Arvioitu päättyminen"

, "Folder"
: "Kansio"

, "Updated by"
: "Päivitetty"

, "Updated Fields:"
: "Päivitetyt kentät:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Johtaja %s on vaihdettu"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Johtaja %s on luotu"

, "Task"
: ""

, "Lead Data"
: ""

, "End Scheduled"
: ""

, "Contacts"
: "Yhteystiedot"

, "Telephone"
: "Puhelin"

, "Email"
: "Sähköposti"

, "low"
: "alhainen"

, "normal"
: "normaali"

, "high"
: "korkea"

, "urgent"
: "tärkeä"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "hallitse jaettujen johtajien kansioita"

, "Create new shared lead folders"
: "Luo uusi jaettu johtajan kansio"

, "manage shared leads favorites"
: "hallitse jaettujen kansioiden suosikeita"

, "Create or update shared leads favorites"
: "Luo tai päivitä jaettujen johtajien suosikkeja"

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
